@@ -1,3 +1,3 @@
 #!/bin/bash
-python src/EasyGit/__init__.py
+python src/__init__.py
 # python test.py
